@@ -183,7 +183,7 @@ class MTCNN(nn.Module):
             specified, will override select_largest:
                     "probability": highest probability selected
                     "largest": largest box selected
-                    "largest_over_theshold": largest box over a certain probability selected
+                    "largest_over_threshold": largest box over a certain probability selected
                     "center_weighted_size": box size minus weighted squared offset from image center
                 (default: {None})
         keep_all {bool} -- If True, all detected faces are returned, in the order dictated by the
@@ -336,9 +336,9 @@ class MTCNN(nn.Module):
                 boxes.append(box[:, :4])
                 probs.append(box[:, 4])
                 points.append(point)
-        boxes = np.array(boxes)
-        probs = np.array(probs)
-        points = np.array(points)
+        boxes = np.array(boxes, dtype=object)
+        probs = np.array(probs, dtype=object)
+        points = np.array(points, dtype=object)
 
         if (
             not isinstance(img, (list, tuple)) and 
